==> certmanager-model-v1alpha2-6.7.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEIssuerDNS01ProviderRoute53Builder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEIssuerDNS01ProviderRoute53Builder extends ACMEIssuerDNS01ProviderRoute53FluentImpl<ACMEIssuerDNS01ProviderRoute53Builder> implements VisitableBuilder<ACMEIssuerDNS01ProviderRoute53,ACMEIssuerDNS01ProviderRoute53Builder>{
  public ACMEIssuerDNS01ProviderRoute53Builder() {
    this(false);
  }
  public ACMEIssuerDNS01ProviderRoute53Builder(Boolean validationEnabled) {
    this(new ACMEIssuerDNS01ProviderRoute53(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderRoute53Builder(ACMEIssuerDNS01ProviderRoute53Fluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEIssuerDNS01ProviderRoute53Builder(ACMEIssuerDNS01ProviderRoute53Fluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEIssuerDNS01ProviderRoute53(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderRoute53Builder(ACMEIssuerDNS01ProviderRoute53Fluent<?> fluent,ACMEIssuerDNS01ProviderRoute53 instance) {
    this(fluent, instance, false);
  }
  public ACMEIssuerDNS01ProviderRoute53Builder(ACMEIssuerDNS01ProviderRoute53Fluent<?> fluent,ACMEIssuerDNS01ProviderRoute53 instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAccessKeyID(instance.getAccessKeyID());
      fluent.withHostedZoneID(instance.getHostedZoneID());
      fluent.withRegion(instance.getRegion());
      fluent.withRole(instance.getRole());
      fluent.withSecretAccessKeySecretRef(instance.getSecretAccessKeySecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEIssuerDNS01ProviderRoute53Builder(ACMEIssuerDNS01ProviderRoute53 instance) {
    this(instance,false);
  }
  public ACMEIssuerDNS01ProviderRoute53Builder(ACMEIssuerDNS01ProviderRoute53 instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAccessKeyID(instance.getAccessKeyID());
      this.withHostedZoneID(instance.getHostedZoneID());
      this.withRegion(instance.getRegion());
      this.withRole(instance.getRole());
      this.withSecretAccessKeySecretRef(instance.getSecretAccessKeySecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEIssuerDNS01ProviderRoute53Fluent<?> fluent;
  Boolean validationEnabled;
  public ACMEIssuerDNS01ProviderRoute53 build() {
    ACMEIssuerDNS01ProviderRoute53 buildable = new ACMEIssuerDNS01ProviderRoute53(fluent.getAccessKeyID(),fluent.getHostedZoneID(),fluent.getRegion(),fluent.getRole(),fluent.getSecretAccessKeySecretRef());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha2-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEIssuerDNS01ProviderRoute53Builder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEIssuerDNS01ProviderRoute53Builder extends ACMEIssuerDNS01ProviderRoute53Fluent<ACMEIssuerDNS01ProviderRoute53Builder> implements VisitableBuilder<ACMEIssuerDNS01ProviderRoute53,ACMEIssuerDNS01ProviderRoute53Builder>{
  public ACMEIssuerDNS01ProviderRoute53Builder() {
    this(false);
  }
  public ACMEIssuerDNS01ProviderRoute53Builder(Boolean validationEnabled) {
    this(new ACMEIssuerDNS01ProviderRoute53(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderRoute53Builder(ACMEIssuerDNS01ProviderRoute53Fluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEIssuerDNS01ProviderRoute53Builder(ACMEIssuerDNS01ProviderRoute53Fluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEIssuerDNS01ProviderRoute53(), validationEnabled);
  }
  public ACMEIssuerDNS01ProviderRoute53Builder(ACMEIssuerDNS01ProviderRoute53Fluent<?> fluent,ACMEIssuerDNS01ProviderRoute53 instance) {
    this(fluent, instance, false);
  }
  public ACMEIssuerDNS01ProviderRoute53Builder(ACMEIssuerDNS01ProviderRoute53Fluent<?> fluent,ACMEIssuerDNS01ProviderRoute53 instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ACMEIssuerDNS01ProviderRoute53());

    if (instance != null) {
      fluent.withAccessKeyID(instance.getAccessKeyID());
      fluent.withHostedZoneID(instance.getHostedZoneID());
      fluent.withRegion(instance.getRegion());
      fluent.withRole(instance.getRole());
      fluent.withSecretAccessKeySecretRef(instance.getSecretAccessKeySecretRef());
      fluent.withAccessKeyID(instance.getAccessKeyID());
      fluent.withHostedZoneID(instance.getHostedZoneID());
      fluent.withRegion(instance.getRegion());
      fluent.withRole(instance.getRole());
      fluent.withSecretAccessKeySecretRef(instance.getSecretAccessKeySecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEIssuerDNS01ProviderRoute53Builder(ACMEIssuerDNS01ProviderRoute53 instance) {
    this(instance,false);
  }
  public ACMEIssuerDNS01ProviderRoute53Builder(ACMEIssuerDNS01ProviderRoute53 instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ACMEIssuerDNS01ProviderRoute53());

    if (instance != null) {
      this.withAccessKeyID(instance.getAccessKeyID());
      this.withHostedZoneID(instance.getHostedZoneID());
      this.withRegion(instance.getRegion());
      this.withRole(instance.getRole());
      this.withSecretAccessKeySecretRef(instance.getSecretAccessKeySecretRef());
      this.withAccessKeyID(instance.getAccessKeyID());
      this.withHostedZoneID(instance.getHostedZoneID());
      this.withRegion(instance.getRegion());
      this.withRole(instance.getRole());
      this.withSecretAccessKeySecretRef(instance.getSecretAccessKeySecretRef());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEIssuerDNS01ProviderRoute53Fluent<?> fluent;
  Boolean validationEnabled;
  public ACMEIssuerDNS01ProviderRoute53 build() {
    ACMEIssuerDNS01ProviderRoute53 buildable = new ACMEIssuerDNS01ProviderRoute53(fluent.getAccessKeyID(),fluent.getHostedZoneID(),fluent.getRegion(),fluent.getRole(),fluent.buildSecretAccessKeySecretRef());
    return buildable;
  }
  
}
